@@ -408,7 +408,18 @@ class Same(Validator):
     password_confirm = 'required|same:password'
 
 
-# =====================================================================
+class Decimal(Validator):
+    price = 'required|decimal'
+
+
+class Exist(Validator):
+    username = 'required|exist:AUTH_USER_MODEL,username'
+
+
+class UniqueAgainst(Validator):
+    username = 'required|unique_against:AUTH_USER_MODEL, username, youngershen'
+
+# ======================================================================================================================
 
 
 class RequiredTestCase(TestCase):
@@ -1512,7 +1523,80 @@ class SameTestCase(TestCase):
             'password_confirm': '1234'
         }
 
-    def teste_valid(self):
+    def test_valid(self):
         validator = self.validator(self.valid_data)
         self.assertTrue(validator.validate())
 
+
+class DecimalTestCase(TestCase):
+    def setUp(self):
+        self.validator = Decimal
+        self.valid_data = {
+            'price': 123.456
+        }
+        self.invalid_data = {
+            'price': 'abcdef'
+        }
+
+    def test_valid(self):
+        validator = self.validator(self.valid_data)
+        self.assertTrue(validator.validate())
+
+        validator = self.validator(self.invalid_data)
+        self.assertFalse(validator.validate())
+
+
+class ExistTestCase(TestCase):
+    def setUp(self):
+        self.setup_users()
+        self.validator = Exist
+        self.valid_data = {
+            'username': 'youngershen'
+        }
+        self.invalid_data = {
+            'username': 'bear'
+        }
+
+    def test_valid(self):
+        validator = self.validator(self.valid_data)
+        self.assertTrue(validator.validate())
+
+        validator = self.validator(self.invalid_data)
+        self.assertFalse(validator.validate())
+
+    @staticmethod
+    def setup_users():
+        from django.contrib.auth.models import User
+        User.objects.create_user(username='youngershen',
+                                 email='shenyangang@163.com',
+                                 password='123456789')
+
+
+class UniqueAgainstTestCase(TestCase):
+    def setUp(self):
+        self.setup_users()
+        self.validator = UniqueAgainst
+        self.valid_data = {
+            'username': 'youngershen'
+        }
+        self.invalid_data = {
+            'username': 'bear'
+        }
+
+    def test_valid(self):
+        validator = self.validator(self.valid_data)
+        self.assertTrue(validator.validate())
+
+        validator = self.validator(self.invalid_data)
+        self.assertFalse(validator.validate())
+
+    @staticmethod
+    def setup_users():
+        from django.contrib.auth.models import User
+        User.objects.create_user(username='youngershen',
+                                 email='shenyangang@163.com',
+                                 password='123456789')
+
+        User.objects.create_user(username='bear',
+                                 email='shenyangang@163.com',
+                                 password='123456789')
