@@ -12,10 +12,6 @@ import datetime
 from copy import deepcopy
 from django.utils.translation import ugettext_lazy as _
 
-# TODO : add check multi field feature to the validator
-
-# TODO : full document support
-
 
 class RuleNotFoundError(Exception):
     message = _('{NAME} rule not found !!!')
@@ -151,6 +147,7 @@ class IDS(BaseRule):
     def check_value(self):
         self.status = True if re.match(self.regex, self.field_value) else False
 
+
 class Cellphone(BaseRule):
     name = 'cellphone'
     regex = r'^([\+]?[0-9]{2})?1[0-9]{10}$'
@@ -1048,7 +1045,7 @@ class Same(BaseRule):
         name = self.get_arg(0)
         if name:
             value = self.data.get(name, None)
-            return str(value) == str(self.field_value)
+            self.status = str(value) == str(self.field_value)
         else:
             raise InvalidRuleParamterError(_('wrong paramter for the Same Rule.'))
 
@@ -1066,6 +1063,62 @@ class Same(BaseRule):
                                    PARAM_VALUE=self.data.get(self.get_arg(0), None))
 
 
+class Decimal(BaseRule):
+    name = 'decimal'
+    message = _('the input value {VALUE} of {FIELD} is not a decimal format number')
+    description = _('')
+
+    def check(self):
+        self.status = self.check_decimal()
+
+    def check_decimal(self):
+        r = r'^[0-9]+(\.[0-9]+)?$'
+        m = re.fullmatch(r, str(self.field_value))
+
+        return True if m else False
+
+    def check_null(self):
+        self.check()
+
+    def check_value(self):
+        self.check()
+
+    def get_message(self):
+        return self.message.format(FIELD=self.field_name,
+                                   VALUE=self.field_value)
+
+
+class Exist(Unique):
+    name = 'exist'
+    message = _('{VALUE} of {MODEL} with {MODEL_FIELD}  not existis in database')
+    description = _('the given value must exist in the table of the database')
+
+    def check_model(self):
+        model_name, model_field = self.args
+        model = self.get_model(model_name)
+        qs = model.objects.filter(**{model_field: self.field_value})
+        return qs.exists()
+
+
+class UniqueAgainst(Unique):
+    name = 'unique_against'
+    message = _('the given {MODEL_NAME} record is exist against '
+                'the {MODEL_FIELD} column by {MODEL_VALUE} with value {VALUE}')
+    description = _('check the given record weather exists in the database against the given column value')
+
+    def check_model(self):
+        model_name, model_field, model_value = self.args
+        model = self.get_model(model_name)
+        qs = model.objects.filter(**{model_field: self.field_value}).exclude(**{model_field: model_value})
+        return not qs.exists()
+
+    def get_message(self):
+        return self.message.format(MODEL_NAME=self.args[0],
+                                   MODEL_FIELD=self.args[1],
+                                   MODEL_VALUE=self.args[2],
+                                   VALUE=self.field_value)
+
+
 class MetaValidator(type):
     def __new__(mcs, *args, **kwargs):
         name, base, attrs = args
@@ -1205,5 +1258,8 @@ default_rules = {
     Username.get_name(): Username,
     Password.get_name(): Password,
     ASCII.get_name(): ASCII,
-    Same.get_name(): Same
+    Same.get_name(): Same,
+    Decimal.get_name(): Decimal,
+    Exist.get_name(): Exist,
+    UniqueAgainst.get_name(): UniqueAgainst
 }
